@@ -3,7 +3,7 @@ from datetime import datetime as Datetime, timezone as Timezone
 import pytest
 
 import pg8000.dbapi
-from pg8000 import converters
+from pg8000.converters import INET_ARRAY, INTEGER
 
 
 # Tests relating to the basic operation of the database driver, driven by the
@@ -180,7 +180,7 @@ def test_executemany(db_table):
     )
 
     cursor.executemany(
-        "select %s",
+        "select CAST(%s AS TIMESTAMP)",
         ((Datetime(2014, 5, 7, tzinfo=Timezone.utc),), (Datetime(2014, 5, 7),)),
     )
 
@@ -192,8 +192,7 @@ def test_executemany_setinputsizes(cursor):
         "CREATE TEMPORARY TABLE t1 (f1 int primary key, f2 inet[] not null) "
     )
 
-    ARRAY_OID = converters.PG_ARRAY_TYPES[converters.INET]
-    cursor.setinputsizes(converters.INTEGER, ARRAY_OID)
+    cursor.setinputsizes(INTEGER, INET_ARRAY)
     cursor.executemany(
         "INSERT INTO t1 (f1, f2) VALUES (%s, %s)", ((1, ["1.1.1.1"]), (2, ["0.0.0.0"]))
     )
